Enum parquet::column::page::Page[][src]

pub enum Page {
    DataPage {
        buf: ByteBufferPtr,
        num_values: u32,
        encoding: Encoding,
        def_level_encoding: Encoding,
        rep_level_encoding: Encoding,
    },
    DataPageV2 {
        buf: ByteBufferPtr,
        num_values: u32,
        encoding: Encoding,
        num_nulls: u32,
        num_rows: u32,
        def_levels_byte_len: u32,
        rep_levels_byte_len: u32,
        is_compressed: bool,
    },
    DictionaryPage {
        buf: ByteBufferPtr,
        num_values: u32,
        encoding: Encoding,
        is_sorted: bool,
    },
}

Parquet Page definition.

List of supported pages. These are 1-to-1 mapped from the equivalent Thrift definitions, except buf which used to store uncompressed bytes of the page.

Variants

Fields of DataPage

Fields of DataPageV2

Fields of DictionaryPage

Methods

impl Page
[src]

Returns PageType for this page.

Returns internal byte buffer reference for this page.

Returns number of values in this page.

Returns this page Encoding.